@@ -7,7 +7,6 @@
 #include "spvm_hash.h"
 #include "spvm_list.h"
 #include "spvm_util_allocator.h"
-#include "spvm_constant_pool.h"
 #include "spvm_opcode_array.h"
 #include "spvm_runtime.h"
 #include "spvm_runtime_allocator.h"
@@ -18,7 +17,6 @@
 #include "spvm_runtime_api.h"
 #include "spvm_opcode_builder.h"
 #include "spvm_jitcode_builder.h"
-#include "spvm_constant_pool_builder.h"
 
 #include "lib_native/SPVM/CORE.native/CORE.c"
 
@@ -53,9 +51,6 @@ int main(int argc, char *argv[])
     exit(1);
   }
   
-  // Build constant pool
-  SPVM_CONSTANT_POOL_BUILDER_build_constant_pool(compiler);
-  
   // Build bytecode
   SPVM_OPCODE_BUILDER_build_opcode_array(compiler);
   
