@@ -7,6 +7,9 @@ enum {
   SPVM_DESCRIPTOR_C_ID_NATIVE,
   SPVM_DESCRIPTOR_C_ID_CONST,
   SPVM_DESCRIPTOR_C_ID_JIT,
+  SPVM_DESCRIPTOR_C_ID_INTERFACE,
+  SPVM_DESCRIPTOR_C_ID_PUBLIC,
+  SPVM_DESCRIPTOR_C_ID_PRIVATE,
 };
 
 extern const char* const SPVM_DESCRIPTOR_C_ID_NAMES[];
