@@ -176,6 +176,8 @@ const char* const SPVM_OPCODE_C_ID_NAMES[] = {
   "CONVERT_LONG_TO_LONG",
   "CONVERT_FLOAT_TO_FLOAT",
   "CONVERT_DOUBLE_TO_DOUBLE",
+  "CONVERT_BYTE_TO_STRING",
+  "CONVERT_SHORT_TO_STRING",
   "CONVERT_INT_TO_STRING",
   "CONVERT_LONG_TO_STRING",
   "CONVERT_FLOAT_TO_STRING",
@@ -272,13 +274,7 @@ const char* const SPVM_OPCODE_C_ID_NAMES[] = {
   "NEW_LONG_ARRAY",
   "NEW_FLOAT_ARRAY",
   "NEW_DOUBLE_ARRAY",
-  "CONCAT_STRING_STRING",
-  "CONCAT_STRING_BYTE",
-  "CONCAT_STRING_SHORT",
-  "CONCAT_STRING_INT",
-  "CONCAT_STRING_LONG",
-  "CONCAT_STRING_FLOAT",
-  "CONCAT_STRING_DOUBLE",
+  "CONCAT",
   "PUSH_EVAL",
   "POP_EVAL",
   "PUSH_ARG",
@@ -327,6 +323,12 @@ const char* const SPVM_OPCODE_C_ID_NAMES[] = {
   "PUSH_ARG_DOUBLE",
   "PUSH_ARG_OBJECT",
   "CHECK_CAST",
+  "STRING_EQ",
+  "STRING_NE",
+  "STRING_GT",
+  "STRING_GE",
+  "STRING_LT",
+  "STRING_LE",
 };
 
 SPVM_OPCODE* SPVM_OPCODE_new(SPVM_COMPILER* compiler) {
