@@ -176,6 +176,8 @@ enum {
   SPVM_OPCODE_C_ID_CONVERT_LONG_TO_LONG,
   SPVM_OPCODE_C_ID_CONVERT_FLOAT_TO_FLOAT,
   SPVM_OPCODE_C_ID_CONVERT_DOUBLE_TO_DOUBLE,
+  SPVM_OPCODE_C_ID_CONVERT_BYTE_TO_STRING,
+  SPVM_OPCODE_C_ID_CONVERT_SHORT_TO_STRING,
   SPVM_OPCODE_C_ID_CONVERT_INT_TO_STRING,
   SPVM_OPCODE_C_ID_CONVERT_LONG_TO_STRING,
   SPVM_OPCODE_C_ID_CONVERT_FLOAT_TO_STRING,
@@ -272,13 +274,7 @@ enum {
   SPVM_OPCODE_C_ID_NEW_LONG_ARRAY,
   SPVM_OPCODE_C_ID_NEW_FLOAT_ARRAY,
   SPVM_OPCODE_C_ID_NEW_DOUBLE_ARRAY,
-  SPVM_OPCODE_C_ID_CONCAT_STRING_STRING,
-  SPVM_OPCODE_C_ID_CONCAT_STRING_BYTE,
-  SPVM_OPCODE_C_ID_CONCAT_STRING_SHORT,
-  SPVM_OPCODE_C_ID_CONCAT_STRING_INT,
-  SPVM_OPCODE_C_ID_CONCAT_STRING_LONG,
-  SPVM_OPCODE_C_ID_CONCAT_STRING_FLOAT,
-  SPVM_OPCODE_C_ID_CONCAT_STRING_DOUBLE,
+  SPVM_OPCODE_C_ID_CONCAT,
   SPVM_OPCODE_C_ID_PUSH_EVAL,
   SPVM_OPCODE_C_ID_POP_EVAL,
   SPVM_OPCODE_C_ID_PUSH_ARG,
@@ -327,6 +323,12 @@ enum {
   SPVM_OPCODE_C_ID_PUSH_ARG_DOUBLE,
   SPVM_OPCODE_C_ID_PUSH_ARG_OBJECT,
   SPVM_OPCODE_C_ID_CHECK_CAST,
+  SPVM_OPCODE_C_ID_STRING_EQ,
+  SPVM_OPCODE_C_ID_STRING_NE,
+  SPVM_OPCODE_C_ID_STRING_GT,
+  SPVM_OPCODE_C_ID_STRING_GE,
+  SPVM_OPCODE_C_ID_STRING_LT,
+  SPVM_OPCODE_C_ID_STRING_LE,
 };
 
 enum {
